@@ -16,7 +16,7 @@
 # Foundation, either version 3 of the License, or (at your option) any later 
 # version.
 # 
-# dostats is distributed in the hope that it will be useful, but WITHOUT ANY 
+# lint is distributed in the hope that it will be useful, but WITHOUT ANY 
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 # FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 # 
@@ -31,7 +31,7 @@
 #' 
 #'  Finders are helper functions that assist in the definition of style checks.
 #'  These function assist by finding the regions that are either included 
-#'  or excluded from check.  Each finder musta accept the following arguments
+#'  or excluded from check.  Each finder must accept the following arguments
 #'  and as well as the variadic argument \code{...}.
 #'  \enumerate{
 #'      \item file
@@ -41,26 +41,25 @@
 #'  Order of arguments is not guaranteed so explicit names use is required, 
 #'  since use of named arguments is guaranteed.
 #'  In addition other arguments may be added later.
-#'  Each finder is expected to retun a \link[lint:conversion]{find} 
+#'  Each finder is expected to return a \link[lint:conversion]{find} 
 #'  formated data.frame.
 #'  
 #'  Custom finders are encouraged, but finders for common classes are 
 #'  included in the package.
 #'  
-#' @param classes with \code{make_class_finder} the parser classes to find.
+#' @param classes with \code{make_class_finder} the \code{\link{getParseData}}
+#'                classes to find.
 #' @param file the file being examined.
 #' @param lines the lines being examined.
-#' @param parse.data data from \code{\link{parser}}
-#' @param ... extra args that include \code{file}, and \code{lines}
+#' @param parse.data data from \code{\link{getParseData}}
+#' @param ... extra arguments that include \code{file}, and \code{lines}
 #' 
 #' @export
 make_class_finder <- function(classes){
     f <- function(..., parse.data) {
-        rows  <- subset(parse.data, parse.data$token.desc %in% classes)
+        rows  <- subset(parse.data, parse.data$token %in% classes)
         if(nrow(rows) == 0) return(empty.find)
-        lrows <- structure(mlply(rows, data.frame)
-                          , split_type=NULL, split_labels=NULL)
-        parse2find(lrows)
+        return(rows[c('line1', 'col1', 'line2', 'col2')])
     }
     structure(f, classes=classes)
 }
@@ -76,6 +75,14 @@ find_comment <- make_class_finder(c("COMMENT", "ROXYGEN_COMMENT"))
 find_basic_comment <- make_class_finder("COMMENT")
 
 
+#' @rdname finders
+#' @export
+find_inside_comment <- function(...,parse.data) {
+    df <- find_basic_comment(..., parse.data = parse.data)
+    df$col1 <- df$col1 + 1
+    subset(df, df$col2 > df$col1 | df$line2 > df$line1)
+}
+
 #' @rdname finders
 #' @export
 find_doc_comment <- make_class_finder(c("ROXYGEN_COMMENT"))
@@ -89,25 +96,31 @@ find_string <- make_class_finder(c("STR_CONST"))
 #' @export
 find_symbol <- make_class_finder("SYMBOL")
 
+#' @rdname finders
+#' @export
+find_number <- make_class_finder("NUM_CONST")
+
+
 #' @rdname finders
 #' @export
 find_function_args <- function(..., parse.data) {
-    ftokens <- subset(parse.data, parse.data$token.desc == "FUNCTION")
+    ftokens <- subset(parse.data, parse.data$token == "FUNCTION")
     ddply(ftokens, "id" , .find_function_args1
          , parse.data = parse.data)[names(empty.find)]
 }
 .find_function_args1 <- function(d, ..., parse.data) {
     p <- d$parent
     function.args <- subset(parse.data, parse.data$parent == d$p & 
-      !(parse.data$token.desc %in% c('expr', 'FUNCTION')))
+      !(parse.data$token %in% c('expr', 'FUNCTION')))
     parse2find(function.args)
 }
   
 #' @rdname finders
 #' @export
 find_function_body <- function(..., lines, file
-                              , parse.data = attr(parser(file))) {
-  f.nodes <- subset(parse.data, parse.data$token.desc == "FUNCTION")
+    , parse.data = getParseData(parse(file, keep.source=TRUE))) {
+  f.nodes <- subset(parse.data, parse.data$token == "FUNCTION")
+  if(!nrow(f.nodes)) return(empty.find)
   body.parents  <- ldply(get_children(f.nodes$parent, parse.data, 1), tail, 1)
   body.contents <- find_children(body.parents, parse.data)
   parse2find(body.contents)
@@ -116,9 +129,10 @@ find_function_body <- function(..., lines, file
 
 #' @rdname finders
 #' @export
-find_call_args <- function(..., file, parse.data = attr(parser(file))) {
+find_call_args <- function(..., file, parse.data = getParseData(parse(file))) {
   call.nodes <- subset(parse.data, 
-    parse.data$token.desc == "SYMBOL_FUNCTION_CALL")
+    parse.data$token == "SYMBOL_FUNCTION_CALL")
+  if(!nrow(call.nodes)) return(empty.find)
   call.args <- 
     llply(call.nodes$id, get_family, parse.data=parse.data, nancestors=2)
   parse2find(call.args)
