@@ -16,7 +16,7 @@
 # Foundation, either version 3 of the License, or (at your option) any later 
 # version.
 # 
-# dostats is distributed in the hope that it will be useful, but WITHOUT ANY 
+# lint is distributed in the hope that it will be useful, but WITHOUT ANY 
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 # FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 # 
@@ -41,7 +41,7 @@
 #'   \item \code{message} The message to be displayed.
 #'   \item \code{include.region} lists regions to restrict the search to.
 #'         Can be a character vector specifying the known regions, or a list of 
-#'         functions that interpret output from \code{\link{parser}}.
+#'         functions that interpret output from \code{\link{getParseData}}.
 #'   \item \code{exclude.region=c('comments', 'string')} lists regions to 
 #'         restrict the search to. Operates the sames as \code{include.region}.
 #'   \item \code{use.lines=T} should the pattern be evaluated in lines (default)
@@ -56,44 +56,41 @@ NULL
 #' @param check a style check
 #' @param ti the test info data
 #' @param only.results if true returns results but does not check for
-#'                     correspondance.  For debugging.
+#'                     correspondence.  For debugging.
 #' 
 #' @return either NULL or throws an error for use with test_that
 #' 
 test_style <- function(check, ti, only.results = F) {
+    p  <- 
     if(is.null(ti$file)) {
         if(is.null(ti$lines)) {
             if(is.null(ti$text))
-                stop("Invalid ti;"
-                     , " one of file, lines, or text, must be specified.")
+                stop( paste0("Invalid ti;"
+                    , " one of file, lines, or text, must be specified."))
             else {
-                ti$file  <- textConnection(ti$text)
-                ti$lines <- textConnection(ti$text)
+                ti$lines <- readLines(ti$file)
+                parse(text=text, keep.source=TRUE)
             }
         } else {
             if(is.null(ti$text)) {
                 ti$text <- paste(ti$lines, collapse='\n')
-                ti$file <- textConnection(ti$text)
             } else {
                 lines <- readLines(textConnection(ti$text))
                 stopifnot(identical(lines, ti$lines))
-                ti$file <- textConnection(ti$text)
             }
+            parse(text=ti$text, keep.source=TRUE)
         }
     } else {
         if(is.null(ti$lines))
             lines <- readLines(ti$file)
-        else 
+        else
             stopifnot(identical(ti$lines, readLines(ti$file)))
+        parse(file=ti$file, keep.source=TRUE)
     }
-    on.exit(if(isOpen(ti$file)){close(ti$file)})
-    p  <- parser(file=ti$file)
-    pd <- 
-    parse.data <- attr(p, 'data')
+    pd <- getParseData(p)
     
     results <- suppressMessages(suppressWarnings({
-        dispatch_test(check, file = ti$file, lines = ti$lines
-                                , parse.data = parse.data)
+        dispatch_test(check, file = ti$file, lines = ti$lines, parse.data = pd)
     }))
     if(only.results) return(results)
     expect_equivalent(results, ti$results)
@@ -101,27 +98,44 @@ test_style <- function(check, ti, only.results = F) {
 }
 
 #' @rdname test_style
-#' @param test.name the name of the test as a string.
+#' @param check.name the name of the test as a string.
+#' 
 #' \code{autotest_style} uses the \code{.testinfo.<<stylename>>} object to 
 #' automatically test styles.  The test info object should be a list with 
 #' \code{$lines} and \code{$results}. The '\code{$lines}' element is the input 
 #' lines and \code{$results} is the find formated data.frame.
 #' 
 #' @export
-autotest_style <- function(test.name) {
-test.name <- as.character(substitute(c(test.name)))[ - 1]
-test_that(test.name
-    , test_style( get(test.name)
-                        , get(paste('.testinfo.', test.name, sep=''))))
+autotest_style <- function(check.name, only.results = FALSE) {
+    if(!is.character(check.name))
+        check.name <- as.character(substitute(c(check.name)))[ - 1]
+    
+    check <- get(check.name)
+    ti <- get(paste0('.testinfo.', check.name))
+    if(only.results)
+        test_style( check, ti, only.results)
+    else 
+        test_that(check.name, test_style( check, ti))
 }
 
 make_ex_span <- function(line1, col1, line2, col2) {
     data.frame( line1 = line1
               ,  col1 = col1
-              , byte1 = col1
               , line2 = line2
-              ,  col2 = col2
-              , byte2 = col2)
+              ,  col2 = col2)
 }
 
+#' @name rr
+#' @aliases .rr
+#' @title make a results row
+#' 
+#' A convenience utility for creating the results rows for autotest style test 
+#' info
+#' @keywords internal
+.rr <- function(line1, col1, line2, col2){
+    data.frame( line1=line1
+              ,  col1=col1
+              , line2=line2
+              ,  col2=col2  )
+}
 
